exceptiontools.MeasureError
===========================

.. inheritance-diagram:: abjad.tools.exceptiontools.MeasureError.MeasureError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MeasureError.MeasureError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MeasureError.MeasureError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
